@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 """
-    Simple backup and restore script for Amazon DynamoDB using boto to work similarly to mysqldump.
+Simple backup and restore script for Amazon DynamoDB using boto to work similarly to mysqldump.
 
-    Suitable for DynamoDB usages of smaller data volume which do not warrant the usage of AWS
-    Data Pipeline for backup/restores/empty.
+Suitable for DynamoDB usages of smaller data volume which do not warrant the usage of AWS
+Data Pipeline for backup/restores/empty.
 
-    dynamodump supports local DynamoDB instances as well (tested with DynamoDB Local).
+dynamodump supports local DynamoDB instances as well (tested with DynamoDB Local).
 """
 
 import argparse
@@ -811,20 +811,24 @@ def prepare_lsi_for_restore(lsi):
     }
 
 
-def prepare_gsi_for_restore(gsi):
+def prepare_gsi_for_restore(gsi, billing_mode):
     """
     This function makes sure that the payload returned for the boto3 API call create_table is compatible
     See: https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/dynamodb.html
     """
-    return {
+    result = {
         "IndexName": gsi["IndexName"],
         "KeySchema": gsi["KeySchema"],
         "Projection": gsi["Projection"],
-        "ProvisionedThroughput": prepare_provisioned_throughput_for_restore(
-            gsi["ProvisionedThroughput"]
-        ),
     }
 
+    if billing_mode != PAY_PER_REQUEST_BILLING_MODE and "ProvisionedThroughput" in gsi:
+        result["ProvisionedThroughput"] = prepare_provisioned_throughput_for_restore(
+            gsi["ProvisionedThroughput"]
+        )
+
+    return result
+
 
 def do_restore(
     dynamo,
@@ -896,6 +900,9 @@ def do_restore(
     original_gsi_read_capacities = []
     if table_global_secondary_indexes is not None:
         for gsi in table_global_secondary_indexes:
+            if "ProvisionedThroughput" not in gsi:
+                continue
+
             # keeps track of original gsi write capacity units. If provisioned capacity is 0, set to
             # RESTORE_WRITE_CAPACITY as fallback given that 0 is not allowed for write capacities
             original_gsi_write_capacity = gsi["ProvisionedThroughput"][
@@ -952,7 +959,8 @@ def do_restore(
 
         if table_global_secondary_indexes is not None:
             optional_args["GlobalSecondaryIndexes"] = [
-                prepare_gsi_for_restore(gsi) for gsi in table_global_secondary_indexes
+                prepare_gsi_for_restore(gsi, billing_mode)
+                for gsi in table_global_secondary_indexes
             ]
 
         while True:
@@ -1060,6 +1068,9 @@ def do_restore(
             if table_global_secondary_indexes is not None:
                 gsi_data = []
                 for gsi in table_global_secondary_indexes:
+                    if "ProvisionedThroughput" not in gsi:
+                        continue
+
                     wcu = gsi["ProvisionedThroughput"]["WriteCapacityUnits"]
                     rcu = gsi["ProvisionedThroughput"]["ReadCapacityUnits"]
                     original_gsi_write_capacity = original_gsi_write_capacities.pop(0)
